/*
 * SimpleApp Demo
 * 
 * Copyright (c) 2010, CodeRight
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice and this list of conditions.
 *   - Redistributions in binary form must reproduce the above
 *     copyright notice and this list of conditions in the 
 *     documentation and/or other materials provided with the 
 *     distribution.
 * 
 * Jazz Desktop Application Framework
 * http://jazz.coderight.nl
 * 
 * Author: Will Boluyt
 */
package nl.coderight.jazz.demo;

import java.awt.Color;

import javax.swing.BorderFactory;

import org.jvnet.substance.SubstanceLegacyDefaultLookAndFeel;

import nl.coderight.jazz.demo.about.AboutController;
import nl.coderight.jazz.demo.contact.ContactController;
import nl.coderight.jazz.demo.event.ContactEvent;
import nl.coderight.jazz.demo.event.MenuEvent;
import nl.coderight.jazz.demo.img.ResourceLoader;
import nl.coderight.jazz.demo.task.LoadContactsTask;

import nl.coderight.jazz.Application;
import nl.coderight.jazz.SplashScreen;
import nl.coderight.jazz.SystemTrayIcon;
import nl.coderight.jazz.util.JazzConfig;
import nl.coderight.jazz.util.JazzUtil;

public class SimpleApp extends Application {	
	private SimpleView simpleView;
	private SimpleModel simpleModel;

	
	/*
	 * Handle contact events.
	 */
	public void handleEvent(ContactEvent evt) {
		switch (evt.getType()) {
		case LOAD_SUCCESS:
			// set contacts to model
			simpleModel.setContacts(evt.getContacts());
			break;
			
		case ADD:
			simpleModel.createContact();
			// fall-through!
		case EDIT:
			// show contact form dialog
			executeController(new ContactController());
			break;
			
		case DELETE:
			// delete contact from model
			simpleModel.deleteContact(simpleModel.getContact());
			break;
		}
	}
	
	/*
	 * Handle menu events.
	 */
	public void handleEvent(MenuEvent evt) {
		switch (evt.getType()) {
		case HELP:
			// when help menu item is clicked do nothing
			System.out.println("Opening help contents...");
			break;
					
		case ABOUT:
			// show about dialog
			executeController(new AboutController());
			break;
		}
	}

	/*
	 * After the view is visible load the contacts. 
	 */
	@Override
	protected void onAfterShowView() {
		super.onAfterShowView();
		executeTask(new LoadContactsTask());
	}

	/*
	 * Before the view becomes visible set the system tray icon.
	 */
	@Override
	protected void onBeforeShowView() {
		super.onBeforeShowView();
		SystemTrayIcon trayIcon = new SystemTrayIcon(JazzUtil.getResourceAsIcon("vcard.png"));
		trayIcon.setToolTipText(simpleView.getTitle());
		setSystemTrayIcon(trayIcon);
	}

	/*
	 * Create the model and view and make the view visible.
	 */
	@Override
	public void execute() {
		simpleModel = new SimpleModel();
		simpleView = new SimpleView();
		setModel(simpleModel);
		setView(simpleView);
		showView();
	}

	/*
	 * Setup the application.
	 */
	@Override
	public void init() {
		// load resource bundle
		setResourceManager(new ResourceLoader("nl/coderight/jazz/demo/i18n/language"));
		// set splash screen
		SplashScreen splashScreen = new SplashScreen();
		splashScreen.setImage(JazzUtil.getResourceAsImage("jazz-logo.jpg"));
		splashScreen.setBorder(BorderFactory.createLineBorder(Color.BLACK, 1));
		setSplashScreen(splashScreen);
		// set custom look and feel
		JazzConfig.getInstance().setDefaultLookAndFeelDecorated(true);
		System.setProperty("Substance.controlFont", "Arial-BOLD-13");
		setLookAndFeel(new SubstanceLegacyDefaultLookAndFeel());
	}

	/*
	 * The start method runs the application on the Event Dispatch Thread.
	 */
	public static void main(String[] args) {
		new SimpleApp().start();
	}

}
